function A=randitriu(I,N,d,varargin)
% FUNCTION fc_amat.random.randitriu
% -- fc_amat.random.randtril(Imax,N,d)
%      Returns a N-by-d-by-d amat object whose matrices are upper triangular  
%      with non zeros elements drawn from discrete uniform distribution on 
%      1:Imax.
%
% -- fc_amat.random.randtril([Imin,Imax],N,d)
%      Returns a N-by-d-by-d amat object whose matrices are upper triangular  
%      with non zeros elements drawn from discrete uniform distribution on 
%      Imin:Imax.
%      
% -- fc_amat.random.randtril(...,key,value)
%      Optional key/value pairs could be used with key
%        - 'nc',  number of columns of matrices (default: d)
%        - 'k',  offset of k diagonals above or below the main diagonal; above 
%          for positive k and below for negative k.
%        - 'complex', if value is true the amat object is complex 
%                     (default false i.e real amat object)
%        - 'class', values are those of Matlab randi function
%
%      See also: fc_amat.random.randtril, fc_amat.random.randntril,
%                class amat, randi
%
  p = inputParser;
  p.addParamValue('nc',d,@isscalar); % number of columns
  p.addParamValue('k',0,@isscalar); % diag number
  p.addParamValue('class','double',@ischar); 
  p.addParamValue('complex',false,@islogical);
  
  p.parse(varargin{:});
  nc=p.Results.nc;k=p.Results.k;
  classname=p.Results.class;
  if p.Results.complex
    A=complex(amat(N,d,nc,classname));
    gen=@(e) complex(randi(I,N,e,classname),randi(I,N,e,classname));
  else
    A=amat(N,d,nc,classname);
    gen=@(e) randi(I,N,e,classname);
  end
  for i=1:min(d,nc)
     s=max(1,i+k);
    if s<=nc, A(i,s:nc)=gen(nc-(s)+1); end
  end
end
